Package: mxcc
Type: Package
Title: Maxwell Control Charts
Version: 0.0.5
Authors@R: c(
    person("Zahid", "Khan", role = "aut"),
    person("Zsolt T.","Kosztyan",email="kosztyan.zsolt@gtk.uni-pannon.hu", role = c("aut", "cre")))
Maintainer: Zsolt T. Kosztyan <kosztyan.zsolt@gtk.uni-pannon.hu>
Description: Computes Control limits, coefficients of control limits, various performance metrics  and depicts control charts for monitoring Maxwell-distributed quality characteristics.
License: GPL (>= 2)
Encoding: UTF-8
LazyData: true
URL: https://github.com/kzst/mxcc
Depends: R (>= 4.00), chi, stats, shotGroups, graphics
RoxygenNote: 7.3.3
NeedsCompilation: no
Packaged: 2026-04-10 09:00:21 UTC; kzst
Author: Zahid Khan [aut],
  Zsolt T. Kosztyan [aut, cre]
Repository: CRAN
Date/Publication: 2026-04-10 09:20:02 UTC
Built: R 4.5.2; ; 2026-04-15 04:59:43 UTC; unix
