# Generated by roxygen2: do not edit by hand

S3method(plot,mxrpc)
S3method(plot,mxspc)
S3method(print,mxrpc)
S3method(print,mxspc)
S3method(print,summary.mxrpc)
S3method(print,summary.mxspc)
S3method(summary,mxrpc)
S3method(summary,mxspc)
export(mxarl)
export(mxewma)
export(mxk)
export(mxm)
export(mxp)
export(mxpw)
export(mxrl)
export(mxrpc)
export(mxspc)
import(chi)
import(graphics)
import(shotGroups)
import(stats)
importFrom(graphics,abline)
importFrom(graphics,legend)
importFrom(graphics,par)
importFrom(graphics,plot)
